// SPDX-FileCopyrightText: 2024 Yury Gubich <blue@macaw.me>
// SPDX-License-Identifier: GPL-3.0-or-later

#pragma once

#include <string>
#include <memory>
#include <vector>

#include "shared/definitions.h"
#include "shared/result.h"
#include "component/core.h"
#include "component/actor.h"

namespace Module {

class Module {
protected:
    Module(const std::shared_ptr<Core>& core, const Shared::Permissions& permissions);

    bool hasPermission(const std::string& permission, const std::shared_ptr<::Actor>& actor) const;

public:
    virtual ~Module() noexcept;

    static Shared::Strings split(const std::string& string, const std::string& delimiter = " ");

    virtual Shared::Result message(const std::shared_ptr<::Actor>& actor, const Shared::Strings& args) = 0;

protected:
    std::shared_ptr<Core> core;
    Shared::Permissions permissions;

};

}
